Index

Trait Index 

pub trait Index: Sealed { }
A type that can be used to index into a serde_yaml::Mapping. See the methods get, get_mut, contains_key, and remove of Value.

This trait is sealed and cannot be implemented for types outside of serde_yaml.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Index for String

Source

impl Index for str

Source

impl<T> Index for &T
where T: ?Sized + Index,

Implementors