pub trait Index: Sealed { }Expand description
A type that can be used to index into a serde_yaml::Mapping. See the
methods get, get_mut, contains_key, and remove of Value.
This trait is sealed and cannot be implemented for types outside of
serde_yaml.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".